pub enum DiscoverError {
InvalidConfig(String),
SpecBuild(String),
GrpcTransport(Error),
GrpcStatus(Box<Status>),
HttpRequest(Error),
HttpStatus {
code: u16,
body: String,
},
InvalidResponse(String),
Rejected {
reason: String,
retry_after_s: Option<i32>,
},
AuthFailed {
reason: String,
},
}Variants
InvalidConfig(String)
SpecBuild(String)
GrpcTransport(Error)
GrpcStatus(Box<Status>)
HttpRequest(Error)
HttpStatus
InvalidResponse(String)
Rejected
AuthFailed
Implementations
Sourceimpl DiscoverError
impl DiscoverError
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
true for errors that indicate a misconfiguration, not a transient failure.
Sync treats these as terminal (Fatal) - the operator must act before the agent can make progress.